Index: trunk/MagicSoft/Simulation/Detector/Camera/input.card
===================================================================
--- trunk/MagicSoft/Simulation/Detector/Camera/input.card	(revision 5273)
+++ trunk/MagicSoft/Simulation/Detector/Camera/input.card	(revision 5274)
@@ -5,9 +5,9 @@
 ct_geom 1
 # Quantum efficiency file:
-qe_file 0  /home/magic/CAMERA_NEW/MagicSoft/Simulation/Detector/Data/qe-emi-coat.RFL.dat
+qe_file 0  /home/pcmagic00/moralejo/MagicSoft/Simulation/Detector/Data/qe-emi-coat.RFL.dat
 # Input file (one per telescope):
 # input_file 0 /data1/magic/reflex/Gamma_zbin0_0_7_1000to1009_w0.rfl
-# Perform calibration run: lambda sigma_lambda phot_per_pixel time_sigma n_events [selected_pixel]
-calibration_run 400. 30. 100. 5. 100 90
+# Perform calibration run: lambda sigma_lambda phot_per_pixel time_fwhm n_events [selected_pixel]
+calibration_run 375. 12. 200. 2.5 5
 # Ascii output file name:
 #data_file ./Gamma_zbin0_0_7_1000to1009_w0.dat
@@ -28,7 +28,8 @@
 nsb_mean 0.13 10
 # Starfield (see Starfieldadder program)
-# starfield_file /home/magic/CAMERA_NEW/MagicSoft/Simulation/Detector/Starfield/starfield.rfl
+# starfield_file /home/pcmagic00/moralejo/MagicSoft/Simulation/Detector/Starfield/starfield.rfl
 # Electronic noise in FADC (sigma in ADC counts): Inner pixels, outer pixels, digital noise: 
-fadc_noise 1.48 2.1 0.
+#fadc_noise 1.48 2.1 0.
+elec_noise_off
 # Mean pedestal per slice (ADC counts):
 fadc_pedestal 10.
@@ -40,20 +41,20 @@
 seeds 66767 45069
 # Directory where NSB database can be found for inner and outer pixels:
-nsb_directory  /home/magic/CAMERA_NEW/MagicSoft/Simulation/Detector/StarLight/inner/
-nsb_dir_outer  /home/magic/CAMERA_NEW/MagicSoft/Simulation/Detector/StarLight/outer/
+nsb_directory  /home/pcmagic00/moralejo/MagicSoft/Simulation/Detector/StarLight/inner/
+nsb_dir_outer  /home/pcmagic00/moralejo/MagicSoft/Simulation/Detector/StarLight/outer/
 #
 # FADC properties: shape of single phe response (1 means realistic one, from
 # Pulpo setup), integral in FADC counts for 1 phe. (3rd argument is ignored 
 # unless gaussian shape - 1st argument=0 - was chosen) :
-#fadc_prop 1 7.8 5.0
+fadc_prop 1 7.8 5.0
 # Same as above for outer pixels:
-#fadc_outer 1 3.2 5.0
+fadc_outer 1 3.2 5.0
 #
 # tentative values for future fast (2 GHz) FADC:
 #
-fadc_prop  0 40. 3.
-fadc_outer 0 15. 3.
+#fadc_prop  0 40. 3.
+#fadc_outer 0  15. 3.
 # FADC sampling frequency and number of FADC slices:
-fadc_GHz 2. 100
+#fadc_GHz 2. 100
 #
 # Write to output trigger information:

Index: trunk/MagicSoft/Simulation/Detector/Camera/creadparam.cxx
===================================================================
--- trunk/MagicSoft/Simulation/Detector/Camera/creadparam.cxx	(revision 5273)
+++ trunk/MagicSoft/Simulation/Detector/Camera/creadparam.cxx	(revision 5274)
@@ -19,7 +19,7 @@
 //=
 //= $RCSfile: creadparam.cxx,v $
-//= $Revision: 1.31 $
+//= $Revision: 1.32 $
 //= $Author: moralejo $ 
-//= $Date: 2004-10-13 17:05:05 $
+//= $Date: 2004-10-14 16:53:49 $
 //=
 //=//////////////////////////////////////////////////////////////////////
@@ -114,5 +114,5 @@
 static float sigma_lambda = 0.;   // Sigma of wavelength distribution for calibration.
 static float phot_per_pix = 0.;   // Average number of photons per inner pixel for calibration.
-static float sigma_time = 0.;     // Time spread (sigma of gaussian) of calibration photons.
+static float fwhm_time = 0.;      // Time spread (FWHM of gaussian) of calibration photons.
 static int   nevents = 0;         // Number of events in calibration run.
 static int   selected_pixel = -1; // Selected pixel: if >= 0 ==> only this pixel is filled! 
@@ -616,5 +616,5 @@
 
       sscanf(line, "%s %f %f %f %f %i %i", token, &lambda, &sigma_lambda, &phot_per_pix,
-	     &sigma_time, &nevents, &selected_pixel);
+	     &fwhm_time, &nevents, &selected_pixel);
       
       CalibrationRun = 1;
@@ -1394,5 +1394,5 @@
   *b = sigma_lambda;
   *c = phot_per_pix;
-  *d = sigma_time;
+  *d = fwhm_time / 2.35;  // Convert from FWHM to sigma of gaussian
   *e = nevents;
   *f = selected_pixel;
@@ -1406,4 +1406,7 @@
 //
 // $Log: not supported by cvs2svn $
+// Revision 1.31  2004/10/13 17:05:05  moralejo
+// *** empty log message ***
+//
 // Revision 1.30  2004/10/12 13:32:02  moralejo
 // *** empty log message ***